==> icons-vue-0.0.5.tgz: package/es/watson-health/launch-study--2/32.js <==
import { _ as _objectSpread2, a as _defineProperty } from '../../chunk-75bb93d0.js';
import { getAttributes } from '@rocketsoftware/icon-helpers';

var virtual_WatsonHealthLaunchStudy_232 = {
  name: 'WatsonHealthLaunchStudy_232',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render: function render(createElement, context) {
    var children = context.children,
        data = context.data,
        listeners = context.listeners,
        props = context.props;
    var attrs = getAttributes(_objectSpread2({
      width: '32',
      height: '32',
      viewBox: '0 0 32 32',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title
    }, data.attrs));
    var svgData = {
      attrs: attrs,
      on: listeners
    };

    if (data.staticClass) {
      svgData.class = _defineProperty({}, data.staticClass, true);
    }

    if (data.class) {
      svgData.class[data.class] = true;
    }

    return createElement('svg', svgData, [props.title && createElement('title', null, props.title), createElement('circle', {
      attrs: {
        "cx": "23",
        "cy": "7",
        "r": "1"
      }
    }), createElement('path', {
      attrs: {
        "d": "M26 4v6H6V4h20m0-2H6a2 2 0 0 0-2 2v6a2 2 0 0 0 2 2h20a2 2 0 0 0 2-2V4a2 2 0 0 0-2-2zm-5.41 19.41L17 17.83V30h-2V17.83l-3.59 3.58L10 20l6-6 6 6-1.41 1.41z"
      }
    }), createElement('path', {
      attrs: {
        "d": "M8 6h12v2H8z"
      }
    }), children]);
  }
};

export default virtual_WatsonHealthLaunchStudy_232;

==> icons-vue-0.2.9.tgz: package/es/watson-health/launch-study--2/32.js <==
import { _ as _objectSpread2, a as _defineProperty } from '../../chunk-75bb93d0.js';
import { getAttributes } from '@rocketsoftware/icon-helpers';

var virtual_WatsonHealthLaunchStudy_232 = {
  name: 'WatsonHealthLaunchStudy_232',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render: function render(createElement, context) {
    var children = context.children,
        data = context.data,
        listeners = context.listeners,
        props = context.props;
    var attrs = getAttributes(_objectSpread2({
      width: '32',
      height: '32',
      viewBox: '0 0 32 32',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title
    }, data.attrs));
    var svgData = {
      attrs: attrs,
      on: listeners
    };

    if (data.staticClass) {
      svgData.class = _defineProperty({}, data.staticClass, true);
    }

    if (data.class) {
      svgData.class[data.class] = true;
    }

    return createElement('svg', svgData, [props.title && createElement('title', null, props.title), createElement('circle', {
      attrs: {
        "cx": "23",
        "cy": "7",
        "r": "1"
      }
    }), createElement('path', {
      attrs: {
        "d": "M26 4v6H6V4H26m0-2H6A2 2 0 0 0 4 4v6a2 2 0 0 0 2 2H26a2 2 0 0 0 2-2V4a2 2 0 0 0-2-2zM20.59 21.41L17 17.83 17 30 15 30 15 17.83 11.41 21.41 10 20 16 14 22 20 20.59 21.41z"
      }
    }), createElement('path', {
      attrs: {
        "d": "M8 6H20V8H8z"
      }
    }), children]);
  }
};

export default virtual_WatsonHealthLaunchStudy_232;
